/****************************************************************************
** Meta object code from reading C++ file 'qquickgraphsscatter_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qtgraphs/src/graphs3d/qml/qquickgraphsscatter_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickgraphsscatter_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QQuickGraphsScatterE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuickGraphsScatter::qt_create_metaobjectdata<qt_meta_tag_ZN19QQuickGraphsScatterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuickGraphsScatter",
        "DefaultProperty",
        "seriesList",
        "QML.Element",
        "Scatter3D",
        "axisXChanged",
        "",
        "QValue3DAxis*",
        "axis",
        "axisYChanged",
        "axisZChanged",
        "selectedSeriesChanged",
        "QScatter3DSeries*",
        "series",
        "handleAxisXChanged",
        "QAbstract3DAxis*",
        "handleAxisYChanged",
        "handleAxisZChanged",
        "handleSeriesMeshChanged",
        "handleMeshSmoothChanged",
        "enable",
        "handleArrayReset",
        "handleItemsAdded",
        "qsizetype",
        "startIndex",
        "count",
        "handleItemsChanged",
        "handleItemsRemoved",
        "handleItemsInserted",
        "cameraRotationChanged",
        "clearSelection",
        "addSeries",
        "removeSeries",
        "axisX",
        "axisY",
        "axisZ",
        "selectedSeries",
        "QQmlListProperty<QScatter3DSeries>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::SignalData<void(QValue3DAxis *)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::SignalData<void(QValue3DAxis *)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'axisZChanged'
        QtMocHelpers::SignalData<void(QValue3DAxis *)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'selectedSeriesChanged'
        QtMocHelpers::SignalData<void(QScatter3DSeries *)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'handleAxisXChanged'
        QtMocHelpers::SlotData<void(QAbstract3DAxis *)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 8 },
        }}),
        // Slot 'handleAxisYChanged'
        QtMocHelpers::SlotData<void(QAbstract3DAxis *)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 8 },
        }}),
        // Slot 'handleAxisZChanged'
        QtMocHelpers::SlotData<void(QAbstract3DAxis *)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 8 },
        }}),
        // Slot 'handleSeriesMeshChanged'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleMeshSmoothChanged'
        QtMocHelpers::SlotData<void(bool)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'handleArrayReset'
        QtMocHelpers::SlotData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleItemsAdded'
        QtMocHelpers::SlotData<void(qsizetype, qsizetype)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 23, 25 },
        }}),
        // Slot 'handleItemsChanged'
        QtMocHelpers::SlotData<void(qsizetype, qsizetype)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 23, 25 },
        }}),
        // Slot 'handleItemsRemoved'
        QtMocHelpers::SlotData<void(qsizetype, qsizetype)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 23, 25 },
        }}),
        // Slot 'handleItemsInserted'
        QtMocHelpers::SlotData<void(qsizetype, qsizetype)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 23, 25 },
        }}),
        // Slot 'cameraRotationChanged'
        QtMocHelpers::SlotData<void()>(29, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'clearSelection'
        QtMocHelpers::MethodData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'addSeries'
        QtMocHelpers::MethodData<void(QScatter3DSeries *)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'removeSeries'
        QtMocHelpers::MethodData<void(QScatter3DSeries *)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QValue3DAxis*>(33, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'axisY'
        QtMocHelpers::PropertyData<QValue3DAxis*>(34, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'axisZ'
        QtMocHelpers::PropertyData<QValue3DAxis*>(35, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'selectedSeries'
        QtMocHelpers::PropertyData<QScatter3DSeries*>(36, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'seriesList'
        QtMocHelpers::PropertyData<QQmlListProperty<QScatter3DSeries>>(2, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuickGraphsScatter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuickGraphsScatter::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickGraphsItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuickGraphsScatterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuickGraphsScatterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QQuickGraphsScatterE_t>.metaTypes,
    nullptr
} };

void QQuickGraphsScatter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuickGraphsScatter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QValue3DAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QValue3DAxis*>>(_a[1]))); break;
        case 2: _t->axisZChanged((*reinterpret_cast<std::add_pointer_t<QValue3DAxis*>>(_a[1]))); break;
        case 3: _t->selectedSeriesChanged((*reinterpret_cast<std::add_pointer_t<QScatter3DSeries*>>(_a[1]))); break;
        case 4: _t->handleAxisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstract3DAxis*>>(_a[1]))); break;
        case 5: _t->handleAxisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstract3DAxis*>>(_a[1]))); break;
        case 6: _t->handleAxisZChanged((*reinterpret_cast<std::add_pointer_t<QAbstract3DAxis*>>(_a[1]))); break;
        case 7: _t->handleSeriesMeshChanged(); break;
        case 8: _t->handleMeshSmoothChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->handleArrayReset(); break;
        case 10: _t->handleItemsAdded((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2]))); break;
        case 11: _t->handleItemsChanged((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2]))); break;
        case 12: _t->handleItemsRemoved((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2]))); break;
        case 13: _t->handleItemsInserted((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[2]))); break;
        case 14: _t->cameraRotationChanged(); break;
        case 15: _t->clearSelection(); break;
        case 16: _t->addSeries((*reinterpret_cast<std::add_pointer_t<QScatter3DSeries*>>(_a[1]))); break;
        case 17: _t->removeSeries((*reinterpret_cast<std::add_pointer_t<QScatter3DSeries*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QValue3DAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QValue3DAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QValue3DAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScatter3DSeries* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstract3DAxis* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstract3DAxis* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstract3DAxis* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScatter3DSeries* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScatter3DSeries* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuickGraphsScatter::*)(QValue3DAxis * )>(_a, &QQuickGraphsScatter::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickGraphsScatter::*)(QValue3DAxis * )>(_a, &QQuickGraphsScatter::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickGraphsScatter::*)(QValue3DAxis * )>(_a, &QQuickGraphsScatter::axisZChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickGraphsScatter::*)(QScatter3DSeries * )>(_a, &QQuickGraphsScatter::selectedSeriesChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScatter3DSeries* >(); break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QValue3DAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QValue3DAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QValue3DAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QValue3DAxis**>(_v) = _t->axisZ(); break;
        case 3: *reinterpret_cast<QScatter3DSeries**>(_v) = _t->selectedSeries(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QScatter3DSeries>*>(_v) = _t->seriesList(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QValue3DAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QValue3DAxis**>(_v)); break;
        case 2: _t->setAxisZ(*reinterpret_cast<QValue3DAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuickGraphsScatter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickGraphsScatter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuickGraphsScatterE_t>.strings))
        return static_cast<void*>(this);
    return QQuickGraphsItem::qt_metacast(_clname);
}

int QQuickGraphsScatter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickGraphsItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QQuickGraphsScatter::axisXChanged(QValue3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuickGraphsScatter::axisYChanged(QValue3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QQuickGraphsScatter::axisZChanged(QValue3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QQuickGraphsScatter::selectedSeriesChanged(QScatter3DSeries * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
