/****************************************************************************
** Meta object code from reading C++ file 'qcategory3daxis.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qtgraphs/src/graphs3d/axis/qcategory3daxis.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qcategory3daxis.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QCategory3DAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto QCategory3DAxis::qt_create_metaobjectdata<qt_meta_tag_ZN15QCategory3DAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCategory3DAxis",
        "QML.Element",
        "Category3DAxis",
        "rowLabelsChanged",
        "",
        "columnLabelsChanged",
        "labelsChanged",
        "labels"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rowLabelsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'columnLabelsChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'labels'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0x70000000 | 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QCategory3DAxis, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QCategory3DAxis::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstract3DAxis::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QCategory3DAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QCategory3DAxisE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QCategory3DAxisE_t>.metaTypes,
    nullptr
} };

void QCategory3DAxis::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QCategory3DAxis *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rowLabelsChanged(); break;
        case 1: _t->columnLabelsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QCategory3DAxis::*)()>(_a, &QCategory3DAxis::rowLabelsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCategory3DAxis::*)()>(_a, &QCategory3DAxis::columnLabelsChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->labels(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabels(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QCategory3DAxis::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCategory3DAxis::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QCategory3DAxisE_t>.strings))
        return static_cast<void*>(this);
    return QAbstract3DAxis::qt_metacast(_clname);
}

int QCategory3DAxis::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstract3DAxis::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QCategory3DAxis::rowLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QCategory3DAxis::columnLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace CheckNotifySignalValidity_ZN15QCategory3DAxisE {
template<typename T> using has_nullary_labelsChanged = decltype(std::declval<T>().labelsChanged());
template<typename T> using has_unary_labelsChanged = decltype(std::declval<T>().labelsChanged(std::declval<QStringList>()));
static_assert(qxp::is_detected_v<has_nullary_labelsChanged, QCategory3DAxis> || qxp::is_detected_v<has_unary_labelsChanged, QCategory3DAxis>,
              "NOTIFY signal labelsChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
