/****************************************************************************
** Meta object code from reading C++ file 'qvalueaxis.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qtgraphs/src/graphs2d/axis/valueaxis/qvalueaxis.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvalueaxis.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10QValueAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto QValueAxis::qt_create_metaobjectdata<qt_meta_tag_ZN10QValueAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QValueAxis",
        "QML.Element",
        "ValueAxis",
        "minChanged",
        "",
        "min",
        "maxChanged",
        "max",
        "rangeChanged",
        "subTickCountChanged",
        "qsizetype",
        "subTickCount",
        "labelFormatChanged",
        "format",
        "labelDecimalsChanged",
        "decimals",
        "tickAnchorChanged",
        "tickAnchor",
        "tickIntervalChanged",
        "tickInterval",
        "zoomChanged",
        "zoom",
        "panChanged",
        "pan",
        "visualMinChanged",
        "newVisualMin",
        "visualMaxChanged",
        "newVisualMax",
        "labelFormat",
        "labelDecimals",
        "visualMin",
        "visualMax"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'minChanged'
        QtMocHelpers::SignalData<void(qreal)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 5 },
        }}),
        // Signal 'maxChanged'
        QtMocHelpers::SignalData<void(qreal)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 7 },
        }}),
        // Signal 'rangeChanged'
        QtMocHelpers::SignalData<void(qreal, qreal)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 5 }, { QMetaType::QReal, 7 },
        }}),
        // Signal 'subTickCountChanged'
        QtMocHelpers::SignalData<void(qsizetype)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'labelFormatChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'labelDecimalsChanged'
        QtMocHelpers::SignalData<void(int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'tickAnchorChanged'
        QtMocHelpers::SignalData<void(qreal)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 17 },
        }}),
        // Signal 'tickIntervalChanged'
        QtMocHelpers::SignalData<void(qreal)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 19 },
        }}),
        // Signal 'zoomChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(20, 4, QMC::AccessPublic, 0x609, QMetaType::Void, {{
            { QMetaType::QReal, 21 },
        }}),
        // Signal 'panChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(22, 4, QMC::AccessPublic, 0x609, QMetaType::Void, {{
            { QMetaType::QReal, 23 },
        }}),
        // Signal 'visualMinChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(24, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::QReal, 25 },
        }}),
        // Signal 'visualMaxChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(26, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::QReal, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'min'
        QtMocHelpers::PropertyData<qreal>(5, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'max'
        QtMocHelpers::PropertyData<qreal>(7, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'labelFormat'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'labelDecimals'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'subTickCount'
        QtMocHelpers::PropertyData<qsizetype>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'tickAnchor'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'tickInterval'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'zoom'
        QtMocHelpers::PropertyData<qreal>(21, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8, 0x609),
        // property 'pan'
        QtMocHelpers::PropertyData<qreal>(23, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9, 0x609),
        // property 'visualMin'
        QtMocHelpers::PropertyData<qreal>(30, QMetaType::QReal, QMC::DefaultPropertyFlags, 10, 0x60b),
        // property 'visualMax'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags, 11, 0x60b),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QValueAxis, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QValueAxis::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractAxis::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QValueAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QValueAxisE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10QValueAxisE_t>.metaTypes,
    nullptr
} };

void QValueAxis::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QValueAxis *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->minChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 1: _t->maxChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->rangeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 3: _t->subTickCountChanged((*reinterpret_cast<std::add_pointer_t<qsizetype>>(_a[1]))); break;
        case 4: _t->labelFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->labelDecimalsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->tickAnchorChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->tickIntervalChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 8: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 9: _t->panChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 10: _t->visualMinChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 11: _t->visualMaxChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::minChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::maxChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal , qreal )>(_a, &QValueAxis::rangeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qsizetype )>(_a, &QValueAxis::subTickCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(const QString & )>(_a, &QValueAxis::labelFormatChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(int )>(_a, &QValueAxis::labelDecimalsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::tickAnchorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::tickIntervalChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::zoomChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::panChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::visualMinChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QValueAxis::*)(qreal )>(_a, &QValueAxis::visualMaxChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->min(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->max(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->labelFormat(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->labelDecimals(); break;
        case 4: *reinterpret_cast<qsizetype*>(_v) = _t->subTickCount(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->tickAnchor(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->tickInterval(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->zoom(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->pan(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->visualMin(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->visualMax(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMin(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setMax(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setLabelFormat(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setLabelDecimals(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setSubTickCount(*reinterpret_cast<qsizetype*>(_v)); break;
        case 5: _t->setTickAnchor(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setTickInterval(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setZoom(*reinterpret_cast<qreal*>(_v)); break;
        case 8: _t->setPan(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QValueAxis::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QValueAxis::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10QValueAxisE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractAxis::qt_metacast(_clname);
}

int QValueAxis::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractAxis::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void QValueAxis::minChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QValueAxis::maxChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QValueAxis::rangeChanged(qreal _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void QValueAxis::subTickCountChanged(qsizetype _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QValueAxis::labelFormatChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QValueAxis::labelDecimalsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QValueAxis::tickAnchorChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QValueAxis::tickIntervalChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QValueAxis::zoomChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QValueAxis::panChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void QValueAxis::visualMinChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void QValueAxis::visualMaxChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
