/****************************************************************************
** Meta object code from reading C++ file 'qdatetimeaxis.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qtgraphs/src/graphs2d/axis/datetimeaxis/qdatetimeaxis.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdatetimeaxis.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QDateTimeAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto QDateTimeAxis::qt_create_metaobjectdata<qt_meta_tag_ZN13QDateTimeAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QDateTimeAxis",
        "QML.Element",
        "DateTimeAxis",
        "minChanged",
        "",
        "min",
        "maxChanged",
        "max",
        "labelFormatChanged",
        "format",
        "tickIntervalChanged",
        "subTickCountChanged",
        "timeZoneChanged",
        "QTimeZone",
        "newTimeZone",
        "zoomChanged",
        "newZoom",
        "panChanged",
        "newPan",
        "visualMinChanged",
        "newMin",
        "visualMaxChanged",
        "newMax",
        "timeZoneFromString",
        "zoneId",
        "timeZoneAsString",
        "labelFormat",
        "subTickCount",
        "tickInterval",
        "timeZone",
        "zoom",
        "pan",
        "visualMin",
        "visualMax"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'minChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 5 },
        }}),
        // Signal 'maxChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 7 },
        }}),
        // Signal 'labelFormatChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'tickIntervalChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subTickCountChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeZoneChanged'
        QtMocHelpers::RevisionedSignalData<void(const QTimeZone &)>(12, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'zoomChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(15, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::QReal, 16 },
        }}),
        // Signal 'panChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(17, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::QReal, 18 },
        }}),
        // Signal 'visualMinChanged'
        QtMocHelpers::RevisionedSignalData<void(const QDateTime &)>(19, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::QDateTime, 20 },
        }}),
        // Signal 'visualMaxChanged'
        QtMocHelpers::RevisionedSignalData<void(const QDateTime &)>(21, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::QDateTime, 22 },
        }}),
        // Method 'timeZoneFromString'
        QtMocHelpers::RevisionedMethodData<QTimeZone(const QString &) const>(23, 4, QMC::AccessPublic, 0x60b, 0x80000000 | 13, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'timeZoneAsString'
        QtMocHelpers::RevisionedMethodData<QString() const>(25, 4, QMC::AccessPublic, 0x60b, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'min'
        QtMocHelpers::PropertyData<QDateTime>(5, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'max'
        QtMocHelpers::PropertyData<QDateTime>(7, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'labelFormat'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'subTickCount'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'tickInterval'
        QtMocHelpers::PropertyData<qreal>(28, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'timeZone'
        QtMocHelpers::PropertyData<QTimeZone>(29, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5, 0x60b),
        // property 'zoom'
        QtMocHelpers::PropertyData<qreal>(30, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6, 0x60b),
        // property 'pan'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7, 0x60b),
        // property 'visualMin'
        QtMocHelpers::PropertyData<QDateTime>(32, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 8, 0x60b),
        // property 'visualMax'
        QtMocHelpers::PropertyData<QDateTime>(33, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 9, 0x60b),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QDateTimeAxis, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QDateTimeAxis::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractAxis::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QDateTimeAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QDateTimeAxisE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QDateTimeAxisE_t>.metaTypes,
    nullptr
} };

void QDateTimeAxis::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QDateTimeAxis *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->minChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 1: _t->maxChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 2: _t->labelFormatChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->tickIntervalChanged(); break;
        case 4: _t->subTickCountChanged(); break;
        case 5: _t->timeZoneChanged((*reinterpret_cast<std::add_pointer_t<QTimeZone>>(_a[1]))); break;
        case 6: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->panChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 8: _t->visualMinChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 9: _t->visualMaxChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 10: { QTimeZone _r = _t->timeZoneFromString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QTimeZone*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->timeZoneAsString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(const QDateTime & )>(_a, &QDateTimeAxis::minChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(const QDateTime & )>(_a, &QDateTimeAxis::maxChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(const QString & )>(_a, &QDateTimeAxis::labelFormatChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)()>(_a, &QDateTimeAxis::tickIntervalChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)()>(_a, &QDateTimeAxis::subTickCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(const QTimeZone & )>(_a, &QDateTimeAxis::timeZoneChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(qreal )>(_a, &QDateTimeAxis::zoomChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(qreal )>(_a, &QDateTimeAxis::panChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(const QDateTime & )>(_a, &QDateTimeAxis::visualMinChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QDateTimeAxis::*)(const QDateTime & )>(_a, &QDateTimeAxis::visualMaxChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->min(); break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->max(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->labelFormat(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->subTickCount(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->tickInterval(); break;
        case 5: *reinterpret_cast<QTimeZone*>(_v) = _t->timeZone(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->zoom(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->pan(); break;
        case 8: *reinterpret_cast<QDateTime*>(_v) = _t->visualMin(); break;
        case 9: *reinterpret_cast<QDateTime*>(_v) = _t->visualMax(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMin(*reinterpret_cast<QDateTime*>(_v)); break;
        case 1: _t->setMax(*reinterpret_cast<QDateTime*>(_v)); break;
        case 2: _t->setLabelFormat(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setSubTickCount(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setTickInterval(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setTimeZone(*reinterpret_cast<QTimeZone*>(_v)); break;
        case 6: _t->setZoom(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setPan(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QDateTimeAxis::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDateTimeAxis::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QDateTimeAxisE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractAxis::qt_metacast(_clname);
}

int QDateTimeAxis::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractAxis::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void QDateTimeAxis::minChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QDateTimeAxis::maxChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QDateTimeAxis::labelFormatChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QDateTimeAxis::tickIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QDateTimeAxis::subTickCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QDateTimeAxis::timeZoneChanged(const QTimeZone & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QDateTimeAxis::zoomChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QDateTimeAxis::panChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QDateTimeAxis::visualMinChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QDateTimeAxis::visualMaxChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
